@@ -60,6 +60,13 @@ mp32wav <- function(samp.rate = 44.1, parallel = 1, from.path = NULL, to.path =
   if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
   if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
+  #if parallel and pb in windows
+  if(parallel > 1 &  pb & Sys.info()[1] == "Windows") {
+    message("parallel with progress bar is currently not available for windows OS")
+    message("running parallel without progress bar")
+    pb <- FALSE
+  } 
+  
   #parallel not available on windows
   if(parallel > 1 & Sys.info()[1] == "Windows")
   {message("parallel computing not availabe in Windows OS for this function")
