@@ -9,5 +9,5 @@
 }
 
 .onLoad <- function(libname, pkgname) {
-if(!Sys.info()[1] == "Windows" & !requireNamespace("pbmcapply",quietly = TRUE)) install.packages("pbmcapply")
+if(!Sys.info()[1] == "Windows" & !requireNamespace("pbmcapply",quietly = TRUE)) install.packages("pbmcapply", repos = "http://cran.us.r-project.org")
   }
